@@ -31,8 +31,8 @@
 
 #include <KContacts/VCardDrag>
 
-#include <KCalCore/Incidence>
-#include <KCalCore/MemoryCalendar>
+#include <KCalendarCore/Incidence>
+#include <KCalendarCore/MemoryCalendar>
 
 #include <KCalUtils/ICalDrag>
 
@@ -133,17 +133,6 @@ void KOrganizerPlugin::slotNewEvent()
     interface()->openEventEditor(QString());
 }
 
-bool KOrganizerPlugin::createDBUSInterface(const QString &serviceType)
-{
-    if (serviceType == QLatin1String("DBUS/Organizer")
-        || serviceType == QLatin1String("DBUS/Calendar")) {
-        if (part()) {
-            return true;
-        }
-    }
-    return false;
-}
-
 bool KOrganizerPlugin::isRunningStandalone() const
 {
     return mUniqueAppWatcher->isRunningStandalone();
@@ -183,16 +172,16 @@ void KOrganizerPlugin::processDropEvent(QDropEvent *event)
     }
 
     if (KCalUtils::ICalDrag::canDecode(event->mimeData())) {
-        KCalCore::MemoryCalendar::Ptr cal(
-            new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+        KCalendarCore::MemoryCalendar::Ptr cal(
+            new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
         if (KCalUtils::ICalDrag::fromMimeData(event->mimeData(), cal)) {
-            KCalCore::Incidence::List incidences = cal->incidences();
+            KCalendarCore::Incidence::List incidences = cal->incidences();
             Q_ASSERT(incidences.count());
             if (!incidences.isEmpty()) {
                 event->accept();
-                KCalCore::Incidence::Ptr i = incidences.first();
+                KCalendarCore::Incidence::Ptr i = incidences.first();
                 QString summary;
-                if (i->type() == KCalCore::Incidence::TypeJournal) {
+                if (i->type() == KCalendarCore::Incidence::TypeJournal) {
                     summary = i18nc("@item", "Note: %1", i->summary());
                 } else {
                     summary = i->summary();
