@@ -115,11 +115,11 @@ void TodoSummaryWidget::updateView()
     //    days to go before to-do is due
     //    which types of to-dos to hide
 
-    KCalCore::Todo::List prList;
+    KCalendarCore::Todo::List prList;
 
     const QDate currDate = QDate::currentDate();
-    const KCalCore::Todo::List todos = mCalendar->todos();
-    for (const KCalCore::Todo::Ptr &todo : todos) {
+    const KCalendarCore::Todo::List todos = mCalendar->todos();
+    for (const KCalendarCore::Todo::Ptr &todo : todos) {
         if (todo->hasDueDate()) {
             const int daysTo = currDate.daysTo(todo->dtDue().date());
             if (daysTo >= mDaysToGo) {
@@ -147,14 +147,14 @@ void TodoSummaryWidget::updateView()
     }
     if (!prList.isEmpty()) {
         prList = Akonadi::ETMCalendar::sortTodos(prList,
-                                                 KCalCore::TodoSortSummary,
-                                                 KCalCore::SortDirectionAscending);
+                                                 KCalendarCore::TodoSortSummary,
+                                                 KCalendarCore::SortDirectionAscending);
         prList = Akonadi::ETMCalendar::sortTodos(prList,
-                                                 KCalCore::TodoSortPriority,
-                                                 KCalCore::SortDirectionAscending);
+                                                 KCalendarCore::TodoSortPriority,
+                                                 KCalendarCore::SortDirectionAscending);
         prList = Akonadi::ETMCalendar::sortTodos(prList,
-                                                 KCalCore::TodoSortDueDate,
-                                                 KCalCore::SortDirectionAscending);
+                                                 KCalendarCore::TodoSortDueDate,
+                                                 KCalendarCore::SortDirectionAscending);
     }
 
     // The to-do print consists of the following fields:
@@ -182,13 +182,13 @@ void TodoSummaryWidget::updateView()
 
         QString str;
 
-        for (const KCalCore::Todo::Ptr &todo : qAsConst(prList)) {
+        for (const KCalendarCore::Todo::Ptr &todo : qAsConst(prList)) {
             bool makeBold = false;
             int daysTo = -1;
 
             // Optionally, show only my To-dos
             /*      if ( mShowMineOnly &&
-                         !KCalCore::CalHelper::isMyCalendarIncidence( mCalendarAdaptor, todo.get() ) ) {
+                         !KCalendarCore::CalHelper::isMyCalendarIncidence( mCalendarAdaptor, todo.get() ) ) {
                     continue;
                   }
             TODO: calhelper is deprecated, remove this?
@@ -265,7 +265,7 @@ void TodoSummaryWidget::updateView()
             // Summary label
             str = todo->summary();
             if (!todo->relatedTo().isEmpty()) {   // show parent only, not entire ancestry
-                KCalCore::Incidence::Ptr inc = mCalendar->incidence(todo->relatedTo());
+                KCalendarCore::Incidence::Ptr inc = mCalendar->incidence(todo->relatedTo());
                 if (inc) {
                     str = inc->summary() + QLatin1Char(':') + str;
                 }
@@ -338,9 +338,9 @@ void TodoSummaryWidget::completeTodo(Akonadi::Item::Id id)
     Akonadi::Item todoItem = mCalendar->item(id);
 
     if (todoItem.isValid()) {
-        KCalCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+        KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
         if (!todo->isReadOnly()) {
-            KCalCore::Todo::Ptr oldTodo(todo->clone());
+            KCalendarCore::Todo::Ptr oldTodo(todo->clone());
             todo->setCompleted(QDateTime::currentDateTime());
             mChanger->modifyIncidence(todoItem, oldTodo);
             updateView();
@@ -350,7 +350,7 @@ void TodoSummaryWidget::completeTodo(Akonadi::Item::Id id)
 
 void TodoSummaryWidget::popupMenu(const QString &uid)
 {
-    KCalCore::Todo::Ptr todo = mCalendar->todo(uid);
+    KCalendarCore::Todo::Ptr todo = mCalendar->todo(uid);
     if (!todo) {
         return;
     }
@@ -401,13 +401,13 @@ QStringList TodoSummaryWidget::configModules() const
     return QStringList() << QStringLiteral("kcmtodosummary.desktop");
 }
 
-bool TodoSummaryWidget::startsToday(const KCalCore::Todo::Ptr &todo)
+bool TodoSummaryWidget::startsToday(const KCalendarCore::Todo::Ptr &todo)
 {
     return todo->hasStartDate()
            && todo->dtStart().date() == QDate::currentDate();
 }
 
-const QString TodoSummaryWidget::stateStr(const KCalCore::Todo::Ptr &todo)
+const QString TodoSummaryWidget::stateStr(const KCalendarCore::Todo::Ptr &todo)
 {
     QString str1, str2;
 
